:mod:`art.attacks`
==================
.. automodule:: art.attacks

Carlini and Wagner Attack
-------------------------
.. autoclass:: CarliniL2Method
   :members:

.. autoclass:: CarliniLInfMethod
   :members:

DeepFool
--------
.. autoclass:: DeepFool
   :members:

Elastic Net Attack
------------------
.. autoclass:: ElasticNet
   :members:

Fast Gradient Method
--------------------
.. autoclass:: FastGradientMethod
   :members:

Basic Iterative Method
----------------------
.. autoclass:: BasicIterativeMethod
   :members:

Projected Gradient Descent
--------------------------
.. autoclass:: ProjectedGradientDescent
   :members:

Jacobian Saliency Map Attack
----------------------------
.. autoclass:: SaliencyMapMethod
   :members:

NewtonFool
----------
.. autoclass:: NewtonFool
   :members:

Spatial Transformations Attack
------------------------------
.. autoclass:: SpatialTransformation
   :members:

Universal Perturbation Attack
-----------------------------
.. autoclass:: UniversalPerturbation
   :members:

Virtual Adversarial Method
--------------------------
.. autoclass:: VirtualAdversarialMethod
   :members:

Base Class
----------
.. autoclass:: Attack
   :members:
